#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Test Visual
# Copyright (C) 2011 Plan Ceibal
# Author: Esteban Arias <earias@plan.ceibal.edu.uy>
# Modified by: Matias Basso <mbasso@plan.ceibal.edu.uy>
# Contact information: comunidad@plan.ceibal.edu.uy
# Plan Ceibal http://www.ceibal.edu.uy
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import gtk
import logging
import gtk.glade
import logging

from sugar.activity import activity
from sugar.graphics.toolbarbox import ToolbarBox
from sugar.activity.widgets import ActivityButton
from sugar.activity.widgets import TitleEntry
from sugar.activity.widgets import StopButton
from about import AboutButton

import ui_inicio
import ui_ishihara
import ui_agudeza
import ui_e_cerca

from about import AboutButton

class TestVisual(activity.Activity):

    def __init__(self, handle):
        activity.Activity.__init__(self, handle)

        self._logger = logging.getLogger('TestVisual-activity')
        self._logger.setLevel(logging.DEBUG)

        self._name = handle

        self._show_toolbox()
        self._show_main_container()

        self.set_brightness('10')

    def _show_form_inicio(self, *args):
        self._main_view.remove(self.ui_actual)
        self.ui_actual = self.ui_inicio.contenedorprincipal
        self._main_view.add(self.ui_actual)
        #self.about_button.emit('clicked')
    def _show_toolbox(self):
        toolbar_box = ToolbarBox()

        activity_button = ActivityButton(self)
        toolbar_box.toolbar.insert(activity_button, 0)
        activity_button.show()

        title_entry = TitleEntry(self)
        toolbar_box.toolbar.insert(title_entry, -1)
        title_entry.show()

        separator = gtk.SeparatorToolItem()
        separator.props.draw = False
        separator.set_expand(True)
        toolbar_box.toolbar.insert(separator, -1)
        separator.show()

        self.about_button = AboutButton(self)
        toolbar_box.toolbar.insert(self.about_button, -1)
        self.about_button.show()

        stop_button = StopButton(self)
        toolbar_box.toolbar.insert(stop_button, -1)
        stop_button.show()

        self.set_toolbar_box(toolbar_box)
        toolbar_box.show()

    def _show_form_ishihara(self, *args):
        self._logger.debug("Mostrar formulario ishihara.")
        self._main_view.remove(self.ui_actual)
        self.ui_actual = self.ui_ishihara.hbox_content        
        self._main_view.add(self.ui_actual)
        self.ui_ishihara._start()

    def _show_form_agudeza(self, *args):
        self._logger.debug("Mostrar formulario agudeza.")
        self._main_view.remove(self.ui_actual)
        self.ui_actual = self.ui_agudeza.hbox_content        
        self._main_view.add(self.ui_actual)
        self.ui_agudeza._start()

    def _show_form_e_cerca(self, *args):
        self._logger.debug("Mostrar formulario e cerca.")
        self._main_view.remove(self.ui_actual)
        self.ui_actual = self.ui_e_cerca.hbox_content        
        self._main_view.add(self.ui_actual)
        self.ui_e_cerca._start()

    def _show_main_container(self):
        self._main_view = gtk.VBox()

        self.ui_inicio = ui_inicio.UIInicio(activity)
        self.ui_inicio.connect('current-form-ishihara', self._show_form_ishihara)
        self.ui_inicio.connect('current-form-agudeza', self._show_form_agudeza)
        self.ui_inicio.connect('current-form-e-cerca', self._show_form_e_cerca)

        self.ui_ishihara = ui_ishihara.UIIshihara(self)
        self.ui_ishihara.connect('current-form-inicio', self._show_form_inicio)

        self.ui_agudeza = ui_agudeza.UIAgudeza(self)
        self.ui_agudeza.connect('current-form-inicio', self._show_form_inicio)

        self.ui_e_cerca = ui_e_cerca.UIECerca(self)
        self.ui_e_cerca.connect('current-form-inicio', self._show_form_inicio)

        self.ui_actual = self.ui_inicio.contenedorprincipal
        self._main_view.add(self.ui_actual)

        self._main_view.show()
        self.set_canvas(self._main_view)

    def set_brightness(self, value):
        try:
            arch=open("/sys/class/backlight/dcon-bl/brightness", "w")
            arch.write(value)
            arch.close()
        except:
            self._logger.error('Error: set brightness.')

	try:
            arch=open("/sys/devices/platform/dcon/output", "w")
            arch.write('0')
            arch.close()
        except:
            self._logger.error('Error: color.')

