from gettext import gettext as _
import gtk
import gobject
import os
from sugar.graphics.toolbutton import ToolButton
from sugar.graphics import style
from sugar.graphics.icon import Icon
from sugar.bundle.activitybundle import ActivityBundle
from sugar.activity.activity import get_bundle_path
from sugar.graphics.toolbutton import ToolButton
from sugar.graphics.toolcombobox import ToolComboBox
from sugar.graphics.combobox import ComboBox
from consejo import ControladorConsejo

SUB_TITULO_SPAN_FORMAT = '<span font_desc = "Arial" size="large" weight="bold">%s</span>'

class AboutPanel(gtk.EventBox):
    exists = False
    def __init__(self, *args, **kwargs):
        super(AboutPanel, self).__init__(*args, **kwargs)

        self.scrollwindow = gtk.ScrolledWindow()
        self.scrollwindow.set_policy(gtk.POLICY_NEVER, gtk.POLICY_AUTOMATIC)
        self.add(self.scrollwindow)
        self.scrollwindow.show()

        self.content_vbox = gtk.VBox()
        self.viewport = gtk.Viewport()
        self.viewport.add(self.content_vbox)
        self.viewport.modify_bg(gtk.STATE_NORMAL, style.COLOR_WHITE.get_gdk_color())
        self.scrollwindow.add(self.viewport)
        self.show_all()

    def add_section(self, text, title=None, img=None):
        if title:
            vbox = gtk.VBox()
            separator = gtk.HSeparator()
            vbox.pack_start(separator, expand=False)
            separator.show()

            label= gtk.Label()
            label.set_markup(SUB_TITULO_SPAN_FORMAT % title)
            label.set_alignment(0, 0)
            vbox.pack_start(label, expand=False)
            label.show()
            self.content_vbox.pack_start(vbox, expand=False)

        vbox = gtk.VBox()
        vbox.set_border_width(style.DEFAULT_SPACING * 2)

        # This is a workaround in sweets
        #view = gtk.Label(text)
        #view.set_line_wrap(True)
        #view.set_alignment(0, 0)

        # FIXME: This is the prefered method, scrolling goes crazy in sweets
        view = gtk.TextView()
        view.unset_flags(gtk.CAN_FOCUS)
        view.set_cursor_visible(False)
        view.set_editable(False)
        view.get_buffer().set_text(text)
        import pango
        view.modify_font(pango.FontDescription("Droid Sans 14"))
        view.set_wrap_mode(gtk.WRAP_WORD)

        vbox.pack_start(view)

        bundle = ActivityBundle(get_bundle_path())
        if img:
            file_img=os.path.join(os.getcwd(),img)
            icon = Icon(pixel_size=style.STANDARD_ICON_SIZE*4, file=file_img)
        else:
            icon = Icon(pixel_size=style.XLARGE_ICON_SIZE*2, file=bundle.get_icon())
        
        icon_button = gtk.Button()
        icon_button.set_image(icon)
        icon_button.unset_flags(gtk.CAN_FOCUS)

        container = gtk.VButtonBox()
        container.add(icon_button)
        container.set_border_width(style.DEFAULT_SPACING * 4)
        container.set_layout(gtk.BUTTONBOX_START)

        vbox.add(container)

        self.content_vbox.pack_start(vbox, expand=False, fill=False)
        view.show()

class AboutButton(ToolButton):
    def __init__(self, activity, **kwargs):
        ToolButton.__init__(self, 'activity-about', **kwargs)
        self.props.tooltip = _('About this activity')
        self.props.accelerator = '<Ctrl>H'
        self.connect('clicked', self.__about_button_clicked_cb, activity)

    def __about_button_clicked_cb(self, button, activity):
        about_dialog = _AboutDialog()
        about_dialog.set_transient_for(self.get_toplevel())
        about_dialog.show_all()

class _AboutDialog(gtk.Window):
    def __init__(self):
        super(_AboutDialog, self).__init__()

        offset = style.GRID_CELL_SIZE
        width = gtk.gdk.screen_width() - offset * 2
        height = gtk.gdk.screen_height() - offset * 2
        self.set_size_request(width, height)
        self.set_border_width(style.LINE_WIDTH)

        self.modify_bg(gtk.STATE_NORMAL, style.COLOR_WHITE.get_gdk_color())
        vbox = gtk.VBox()
        self.add(vbox)
        vbox.show()
        
        self.set_position(gtk.WIN_POS_CENTER_ALWAYS)
        self.set_decorated(False)
        self.set_resizable(False)
        self.set_modal(True)

        self.toolbar = _DialogToolbar()
        self.toolbar.connect('stop-clicked', self._stop_clicked_cb)
        self.toolbar.connect('infopanel-changed', self._info_changed_cb)
        vbox.pack_start(self.toolbar, False)

        hbox = gtk.HBox()
        hbox.set_border_width(style.DEFAULT_SPACING * 2)
        hbox.set_spacing(style.DEFAULT_SPACING)
        #hbox.pack_start(container, expand=False, fill=False)
        vbox.pack_start(hbox, expand=True, fill=True)

        self.content_vbox = gtk.VBox()
        self.content_vbox.set_border_width(style.DEFAULT_SPACING)
        hbox.pack_start(self.content_vbox, expand=True, fill=True)

        self._notebook = gtk.Notebook()
        self._notebook.set_show_tabs(False)

        c = ControladorConsejo()
        index = 0
        for unConsejo in sorted(c.losConsejos):
            panel = AboutPanel()
            panel.add_section(unConsejo.descripcion, unConsejo.titulo,unConsejo.img_path)
            index += 10
            self._notebook.append_page(panel)
            self.toolbar.info_combo.append_item(index, unConsejo.titulo)
            self.toolbar.panel[index]=panel

        self.content_vbox.pack_start(self._notebook)
        self.toolbar.info_combo.set_active(0)

        self.connect('realize', self._realize_cb)

    def _stop_clicked_cb(self, source):
        self.destroy()

    def _info_changed_cb(self, source):
        active = self.toolbar.info_combo.get_active()
        self._notebook.set_current_page(active)

    def _realize_cb(self, source):
        self.window.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_DIALOG)
        self.window.set_accept_focus(True)

class _DialogToolbar(gtk.Toolbar):
    panel = {} 
    __gsignals__ = {
        'stop-clicked'       : (gobject.SIGNAL_RUN_LAST, None, ()),
        'infopanel-changed': (gobject.SIGNAL_RUN_FIRST,
                          gobject.TYPE_NONE,
                          ([])),
    }
    def __init__(self):
        super(_DialogToolbar, self).__init__()

        self._add_separator()
        icon_button = Icon(pixel_size=style.STANDARD_ICON_SIZE,
                            icon_name='activity-about')
        #icon_button.connect('clicked', self._icon_button_clicked_cb)
        self._add_widget(icon_button)
        icon_button.unset_flags(gtk.CAN_FOCUS)

        self._add_separator()
        self.info_combo = ComboBox()
        self.info_combo.props.sensitive = True
        self._info_changed_cb_id = self.info_combo.connect('changed', 
                                                self._info_changed_cb)
        combotool = ToolComboBox(self.info_combo)
        self.insert(combotool, -1)
        combotool.show()

        self._back = ToolButton('go-previous-paired')
        self._back.props.sensitive = False
        self._back.connect('clicked', self.__go_back_cb)
        self.insert(self._back, -1)
        self._back.show()

        self._forward = ToolButton('go-next-paired')
        #self._forward.props.sensitive = False
        self._forward.connect('clicked', self.__go_forward_cb)
        self.insert(self._forward, -1)
        self._forward.show()

        self._add_separator(expand=True)

        stop = ToolButton(icon_name='dialog-cancel')
        stop.set_tooltip(_('Done'))
        stop.connect('clicked', self._stop_clicked_cb)
        self.add(stop)

    def __go_back_cb(self, widget):
        active = max(0, self.info_combo.get_active() - 1)
        self.info_combo.set_active(active)
        self._info_changed_cb(widget)
        self.__set_nav_buttons(active)

    def __go_forward_cb(self, widget):
        active = min(len(self.panel.keys())-1, self.info_combo.get_active() + 1)
        self.info_combo.set_active(active)
        self._info_changed_cb(widget)
        self.__set_nav_buttons(active)
        
    def __set_nav_buttons(self,active):
        if active==0:
            self._back.props.sensitive = False
        else:
            self._back.props.sensitive = True 

        if active==len(self.panel.keys())-1:
            self._forward.props.sensitive = False
        else:
            self._forward.props.sensitive = True 

    def _info_changed_cb(self, widget):
        self.__set_nav_buttons(widget.get_active())
        self.emit('infopanel-changed')

    def _add_separator(self, expand=False):
        separator = gtk.SeparatorToolItem()
        separator.set_expand(expand)
        separator.set_draw(False)
        self.add(separator)

    def _add_widget(self, widget):
        tool_item = gtk.ToolItem()
        tool_item.add(widget)
        self.add(tool_item)

    def _stop_clicked_cb(self, button):
        self.emit('stop-clicked')
