#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Test Visual
# Copyright (C) 2011 Plan Ceibal
# Author: Esteban Arias <earias@plan.ceibal.edu.uy>
# Modified by: Matias Basso <mbasso@plan.ceibal.edu.uy>
# Contact information: comunidad@plan.ceibal.edu.uy
# Plan Ceibal http://www.ceibal.edu.uy
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import gtk
import gtk.glade
import os
from os.path import join
import pango
import random
import logging
import gobject
from gobject import SIGNAL_RUN_FIRST, TYPE_PYOBJECT
gobject.threads_init()

from display import Display

TEST_NUMEROS=['0','7','4','1']
NUMEROS=['0','1','2','3','4','5','6','7','8','9']

SIZES_3M={1: 113.4,
          2: 56.7,
          3: 36.8,
          4: 28.3,
          5: 25.5,
          6: 17.0,
          7: 14.1,
          8: 12.7,
          9: 11.3,
          10: 10.6,
          }

TEXT_START="ALÉJATE 3 METROS \n\n \
TAPA EL OJO CON TU MANO SIN APRETARLO.\n\n \
COMO HACIENDO UNA CARPITA. \n\n \
INDICA EL NÚMERO QUE VES. \n\n \
PRESIONA UNA TECLA PARA COMENZAR."
TEXT_DESC_IZQ = "TAPA EL OJO IZQUIERDO CON TU MANO.\n\n \
PRESIONA EL NÚMERO QUE VES."
TEXT_DESC_DER = "TAPA EL OJO DERECHO CON TU MANO.\n\n \
PRESIONA EL NÚMERO QUE VES."
TEXT_MISS = "Oh!-Oh! INDICASTE MAL EL NÚMERO... \n\n \
VUELVE A INTENTARLO !!!!"
TEXT_NEXT = "BIEN! CONTINUA CON EL SIGUIENTE NIVEL... \n\n \
INDICA EL NÚMERO QUE VES."
TEXT_FAILTEST = "NO PASASTE LA PRUEBA DE VISIÓN...\n\n \
DEBERÍAS IR AL OFTALMÓLOGO \n\n \
PARA QUE TE EXAMINE BIEN.\n\n \
PUEDE QUE TENGAS ALGÚN PROBLEMA VISUAL."
TEXT_EXITO = "REALIZASTE BIEN EL EXAMEN VISUAL.\n\n \
TE RECOMENDAMOS TE CONTROLES \n\n \
EN EL CENTRO DE SALUD CON OFTALMÓLOGO \n\n \
PARA UN EXAMEN MÁS COMPLETO DE TUS OJOS."

SUB_TITULO_SPAN_FORMAT = '<span font_desc = "Arial" size="large" weight="bold">%s</span>'

_logger = logging.getLogger('TestVisual-activity')
_logger.setLevel(logging.DEBUG)

class UIAgudeza(gobject.GObject):
    __gtype_name__ = 'UIEAgudeza'

    __gsignals__ = {
        'current-form-inicio': (SIGNAL_RUN_FIRST, None, [TYPE_PYOBJECT]),
    }

    def __init__(self, activity):
        self.__gobject_init__()
        
        self.activity = activity

        self.xml = gtk.glade.XML("GUI/gui_agudeza.glade")
        self.ventanaprincipal = self.xml.get_widget('ventana_numero')
        self.contenedorprincipal = self.ventanaprincipal.get_child()
        self.ventanaprincipal.remove(self.contenedorprincipal)

        self.hbox_content = gtk.EventBox()
        self.hbox_content.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse('white'))
        self.hbox_content.add(self.contenedorprincipal)
        self.hbox_content.show()
        
        self.texto = Display()
        self.texto.show_all()

        self.content_text = self.texto
        self.contenedorprincipal.add(self.content_text)

        self.lbl_nivel = self.xml.get_widget('lbl_nivel')

        self.content_numero = self.xml.get_widget('tbl_numero')
        self.content_numero.hide_all()

        self.hbox_numero = self.xml.get_widget('hbox_numero')
        self.lbl_numero = self.xml.get_widget('lbl_numero')

        self.ojo_izquierdo = True
        
    def _start(self):
        self.first_Time = True
        self._vidas = 2
        self._show_result = False
        self.equivoco_en_nivel = False
        self.nivel_actual = 1
        self.numero_actual = self.generar_numero()
        self.agudeza_event_key_press = self.activity.connect('key-press-event', self.on_key_press)
        self.show_start()

    def on_key_press(self, widget, event):
        if event.keyval == gtk.keysyms.Escape or self._show_result:
            self._exit()
            return

        if self.first_Time:
            self.show_numero(self.numero_actual)
            self.first_Time = False
        else:
            k = gtk.gdk.keyval_name(event.keyval)
            if k in NUMEROS:
                if self.numero_actual == k:
                    _logger.debug("yes")
                    self.show_text(TEXT_NEXT)
                    self.nivel_actual = self.nivel_actual + 1
                    if (self.nivel_actual > len(SIZES_3M) - 1):
                        self._show_result = True
                    #
                    if self._vidas == 1:
                        self._vidas = 2
                    #
                else:
                    _logger.debug("no")
                    self._vidas = self._vidas - 1
                    if self._vidas == 0 or self._vidas == 1:
                        self._show_result = True

                if (self.nivel_actual < len(SIZES_3M)):
                    self.numero_actual = self.generar_numero()
                    self.show_numero(self.numero_actual)

                if self._show_result:
                    self.show_result()

    def show_text(self, text):
        self.texto.set_image(join(os.getcwd(), 'GUI', 'texto_fondo.svg'), 800, 570)
        self.content_text.show_all()
        self.texto.set_markup(SUB_TITULO_SPAN_FORMAT % text)

    def show_numero(self, num):
        if self.first_Time:
            if (self.ojo_izquierdo):
                self.show_text(TEXT_DESC_IZQ)
            else:
                self.show_text(TEXT_DESC_DER)
        self.content_numero.show_all()
        self.lbl_numero.set_text(str(num))
        self.lbl_numero.modify_font(pango.FontDescription("sans bold " + str(SIZES_3M[self.nivel_actual])))
        self.show_nivel(str(self.nivel_actual))

    def show_nivel(self, nivel):
        self.lbl_nivel.set_text(nivel)
        
    def remove_numero(self):
        self.content_numero.hide_all()

    def show_result(self):        
        if self._vidas == 0:
            text = TEXT_FAILTEST
            gobject.idle_add(self.remove_numero)
            self._vidas = 2
            self.show_end(text)
        elif self._vidas == 1:
            text = TEXT_MISS
            self._show_result = False
            self.show_text(text)
        else:
            text = TEXT_EXITO
            gobject.idle_add(self.remove_numero)
            self._vidas = 2
            self.show_end(text)

    def on_pressed_btn_inicio(self, widget):
        self._exit()

    def generar_numero(self):
        return random.choice(TEST_NUMEROS)

    def _exit(self):
        self.activity.disconnect(self.agudeza_event_key_press)
        self.emit('current-form-inicio', None)

    def show_start(self):
        self.content_numero.hide_all()
        self.texto.set_image(join(os.getcwd(), 'GUI', 'texto_fondo2.svg'), 800, 570)
        self.content_text.show_all()
        self.texto.set_markup(SUB_TITULO_SPAN_FORMAT % TEXT_START)

    def show_end(self, text):
        self.texto.set_image(join(os.getcwd(), 'GUI', 'texto_fondo2.svg'), 800, 570)
        self.content_text.show_all()
        if self.ojo_izquierdo:
            text = text + "\n\n INTENTA CON TU OTRO OJO"
        self.ojo_izquierdo = not self.ojo_izquierdo
        self.texto.set_markup(SUB_TITULO_SPAN_FORMAT % text)