#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Test Visual
# Copyright (C) 2011 Plan Ceibal
# Author: Esteban Arias <earias@plan.ceibal.edu.uy>
# Contact information: comunidad@plan.ceibal.edu.uy
# Plan Ceibal http://www.ceibal.edu.uy
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import gtk
import gtk.glade
import random
import logging
import gobject
from gobject import SIGNAL_RUN_FIRST, TYPE_PYOBJECT
gobject.threads_init()

import e
from e import E
from e import MAP_KEY

TEXT_DESC = "TAPA EL OJO CON TU MANO SIN APRETARLO \n \
COMO HACIENDO UNA CARPITA. \n\n \
PRESIONA LAS FLECHAS O LAS TECLAS DE JUEGO \n\n \
PARA INDICAR EL SENTIDO DE LA LETRA 'E'"
TEXT_MISS = "Oh!-Oh! INDICASTE MAL EL SENTIDO DE LA LETRA. VUELVE A INTENTARLO\n\n"
TEXT_NEXT = "BIEN! CONTINUA CON EL SIGUIENTE NIVEL ... \n\n"  + TEXT_DESC
TEXT_FAILTEST = "NO PASASTE LA PRUEBA DE VISIÓN... \n\n \
DEBERÍAS IR AL OFTALMÓLOGO PARA QUE TE EXAMINE BIEN.\n\n \
PUEDE QUE TENGAS ALGÚN PROBLEMA VISUAL."
TEXT_EXITO = "REALIZASTE BIEN EL EXAMEN VISUAL.\n\n \
PERO TE RECOMENDAMOS TE CONTROLES EN EL CENTRO DE SALUD \n\n \
CON OFTALMÓLOGO PARA UN EXAMEN MÁS COMPLETO DE TUS OJOS."

SUB_TITULO_SPAN_FORMAT = '<span font_desc = "Arial" size="large" weight="bold">%s</span>'

_logger = logging.getLogger('TestVisual-activity')
_logger.setLevel(logging.DEBUG)

class UIECerca(gobject.GObject):
    __gtype_name__ = 'UIECerca'

    __gsignals__ = {
        'current-form-inicio': (SIGNAL_RUN_FIRST, None, [TYPE_PYOBJECT]),
    }

    def __init__(self, activity):
        self.__gobject_init__()

        self.activity = activity

        self.xml = gtk.glade.XML("GUI/gui_e_cerca.glade")
        self.ventanaprincipal = self.xml.get_widget('ventana_e_cerca')
        self.contenedorprincipal = self.ventanaprincipal.get_child()
        self.ventanaprincipal.remove(self.contenedorprincipal)

        self.hbox_content = gtk.EventBox()
        self.hbox_content.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse('white'))
        self.hbox_content.add(self.contenedorprincipal)
        self.hbox_content.show()

        self.lbl_mensaje = self.xml.get_widget('lbl_mensaje')       
        self.hbox_imagen = self.xml.get_widget('hbox_imagen')

    def _start(self):
        self._vidas = 2
        self._show_result = False
        self.equivoco_en_nivel = False
        self.nivel_actual = 1
        self.show_text(SUB_TITULO_SPAN_FORMAT % TEXT_DESC)
        self.e_actual = self.generate_image(self.nivel_actual)
        self.e_cerca_key_press_event = self.activity.connect('key-press-event', self.on_key_press)
        self.show_e(self.e_actual)        

    def on_key_press(self, widget, event):
        if event.keyval == gtk.keysyms.Escape or self._show_result:
            self._exit()
            return

        k = gtk.gdk.keyval_name(event.keyval)
        if k in MAP_KEY:
            key_value = MAP_KEY[k]
            if self.e_actual.number == key_value:
                _logger.debug("yes")
                self.show_text(TEXT_NEXT)
                self.nivel_actual = self.nivel_actual + 1
                if (self.nivel_actual > len(e.SIZES_3M) - 1):
                    self._show_result = True
                #
                if self._vidas == 1:
                    self._vidas = 2
                #
            else:
                _logger.debug("no")
                self.show_text(TEXT_MISS)
                self._vidas = self._vidas - 1
                if self._vidas == 0:
                    self._show_result = True

            if self._show_result:
                self.show_result()
            elif self._vidas > 0:
                self.remove_e(self.e_actual)
                self.e_actual = self.generate_image(self.nivel_actual)
                self.show_e(self.e_actual)

    def show_text(self, text):
        self.lbl_mensaje.set_markup(SUB_TITULO_SPAN_FORMAT % text)

    def show_e(self, img):
        self.hbox_imagen.add(img)
        self.hbox_imagen.show_all()

    def remove_e(self, img):
        self.hbox_imagen.remove(img)

    def show_result(self):
        self.hbox_imagen.hide_all()
        self.remove_e(self.e_actual)
        if self._vidas == 0:
            text = TEXT_FAILTEST
        else:
            text = TEXT_EXITO
        self.show_text(text)

    def on_pressed_btn_inicio(self, widget):
        self._exit()

    def generate_image(self, scale):
        position = random.choice([6, 2, 4, 8])
        return E(position,scale)

    def _exit(self):
        self.activity.disconnect(self.e_cerca_key_press_event)
        self.remove_e(self.e_actual)
        self.emit('current-form-inicio', None)