#!/usr/bin/env python
# -*- coding: UTF-8 -*-
#
# Test Visual
# Copyright (C) 2011 Plan Ceibal
# Author: Esteban Arias <earias@plan.ceibal.edu.uy>
# Modified by: Matias Basso <mbasso@plan.ceibal.edu.uy>
# Contact information: comunidad@plan.ceibal.edu.uy
# Plan Ceibal http://www.ceibal.edu.uy
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import gtk
import logging
import gtk.glade
import os
from os.path import join
import gobject
from gobject import SIGNAL_RUN_FIRST, TYPE_PYOBJECT
gobject.threads_init()

from sugar.graphics import style
from ishihara import Ishihara

ISHIHARA_PATH = join(os.getcwd(), 'ishihara', 'img')

_logger = logging.getLogger('TestVisual-activity')
_logger.setLevel(logging.DEBUG)

TEXT_START="MIRA EL DIBUJO CON COLORES \n\n \
Y BUSCA EN SU INTERIOR EL NÚMERO ESCONDIDO.\n\n \
MARCA EN LA COMPUTADORA EL NÚMERO QUE VES.\n\n \
PRESIONA UNA TECLA PARA COMENZAR."

TEXT_END_FAIL="PUEDE QUE ESTÉS TENIENDO PROBLEMAS\n\n \
PARA VER LOS COLORES ROJOS Y VERDES.\n\n \
DEBERÍAS IR AL OFTALMÓLOGO\n\n \
PARA QUE TE EXAMINE BIEN."

TEXT_END_PASS="REALIZASTE BIEN EL EXAMEN VISUAL.\n\n \
PERO TE RECOMENDAMOS TE CONTROLES\n\n \
EN EL CENTRO DE SALUD CON OFTALMÓLOGO\n\n \
PARA UN EXAMEN MÁS COMPLETO DE TUS OJOS."

SUB_TITULO_SPAN_FORMAT = '<span font_desc = "Arial" size="large" weight="bold">%s</span>'

from display import Display

class UIIshihara(gobject.GObject):
    __gtype_name__ = 'UIIshihara'

    __gsignals__ = {
        'current-form-inicio': (SIGNAL_RUN_FIRST, None, [TYPE_PYOBJECT]),
    }

    def __init__(self, activity):
        self.__gobject_init__()
        
        self.activity = activity
        self.las_ishiharas = []
        self.ishihara_index = 0
        self.resultados_correctos = 0
        self.first_Time = True
        self.miss = True

        self.xml = gtk.glade.XML("GUI/gui_ishihara.glade")
        self.ventanaprincipal = self.xml.get_widget('ventana_ishihara')
        self.contenedorprincipal = self.ventanaprincipal.get_child()
        self.ventanaprincipal.remove(self.contenedorprincipal)

        self.hbox_content = gtk.EventBox()
        self.hbox_content.modify_bg(gtk.STATE_NORMAL, gtk.gdk.color_parse('white'))
        self.hbox_content.add(self.contenedorprincipal)
        self.hbox_content.show()

        self.texto = Display()
        self.texto.set_image(join(os.getcwd(), 'GUI', 'texto_fondo2.svg'), 800, 570)
        self.texto.show_all()

        self.content_text = self.texto
        self.contenedorprincipal.add(self.content_text)

        self.lbl_mensaje = self.xml.get_widget('lbl_mensaje')        

        self.content_ishihara = self.xml.get_widget('tbl_ishihara')
        self.content_ishihara.hide_all()

        self.img_ishihara = self.xml.get_widget('img_ishihara')
        
    def _start(self):
        self.las_ishiharas = []
        self.ishihara_index = 0
        self.resultados_correctos = 0
        self.first_Time = True
        self.miss = False
        self.exit = False
        self.cargar_ishiharas()
        self.ishihara_key_prses_event = self.activity.connect('key-press-event', self.on_key_press)
        self.show_start()
        
    def cargar_ishiharas(self):
        for base, dirs, files in os.walk(ISHIHARA_PATH):
            las_ishiharas = files
        for f in files:
            i = Ishihara()
            i.file_path = join(os.getcwd(), ISHIHARA_PATH, f)
            i.number = f[0:len(f)-4]
            self.las_ishiharas.append(i)

    def on_key_press(self, widget, event):
        if event.keyval == gtk.keysyms.Escape or self.exit:
            self._exit()

        if self.first_Time:
            self.show_ishihara(self.ishihara_index)
            self.first_Time = False

        else:
            k = gtk.gdk.keyval_name(event.keyval)

            if k in ['0','1','2','3','4','5','6','7','8','9']:

                if k == self.get_ishihara_actual().number:
                    self.resultados_correctos += 1
                    self.ishihara_index += 1

                    if self.ishihara_index < len(self.las_ishiharas):
                        self.show_ishihara(self.ishihara_index)

                else:
                    self.miss = True
            
            if self.miss:
                self.exit = True
                self.show_result(TEXT_END_FAIL)

            elif self.ishihara_index == len(self.las_ishiharas):
                self.exit = True
                self.show_result(TEXT_END_PASS)
            
    def show_ishihara(self, index):
        self.content_text.hide_all()
        self.content_ishihara.show_all()
        ishihara = self.las_ishiharas[index]
        pixbufanim = gtk.gdk.pixbuf_new_from_file_at_size(ishihara.file_path, style.zoom(700), style.zoom(690))
        self.img_ishihara.set_from_pixbuf(pixbufanim)
    
    def get_ishihara_actual(self):
        if self.ishihara_index < len(self.las_ishiharas):
            ishihara = self.las_ishiharas[self.ishihara_index]
            return ishihara
        return 0

    def show_result(self, text):
        self.content_ishihara.hide_all()
        self.texto.set_markup(SUB_TITULO_SPAN_FORMAT % text)
        self.content_text.show_all()

    def _exit(self):
        self.activity.disconnect(self.ishihara_key_prses_event)
        self.content_text.hide_all()
        self.content_ishihara.hide_all()
        self.emit('current-form-inicio', None)

    def show_start(self):
        self.content_ishihara.hide_all()
        self.content_text.show_all()
        self.texto.set_markup(SUB_TITULO_SPAN_FORMAT % TEXT_START)